@@ -161,7 +161,7 @@ int skip_cb(GtkWidget *widget, GdkEvent *event, gpointer *data)
 		if(cd.cur_t < cd.last_t)
 		{   
 		    cd.cur_t++;
-		    tcd_playtracks(&cd,cd.cur_t, cd.last_t);
+		    tcd_playtracks(&cd,cd.cur_t, cd.last_t, prefs.only_use_trkind);
 		    if(cd.play_method==REPEAT_TRK)
 			cd.repeat_track = cd.cur_t;
 		}
@@ -172,7 +172,7 @@ int skip_cb(GtkWidget *widget, GdkEvent *event, gpointer *data)
 		{
 		    if( (cd.t_sec+(cd.t_min*60)) < 10 )
 			cd.cur_t--;
-		    tcd_playtracks( &cd,cd.cur_t, cd.last_t );
+		    tcd_playtracks( &cd,cd.cur_t, cd.last_t, prefs.only_use_trkind);
 				                                                             
 		    if( cd.play_method==REPEAT_TRK )
 			cd.repeat_track = cd.cur_t;
@@ -563,8 +563,11 @@ void adjust_status(void)
 
 gint slow_timer( gpointer *data )
 {
+    tcd_post_init(&cd);
+    adjust_status();
+
     /* see if we need to make a new menu */
-    if( cd.cddb_id != cur_goto_id )
+    if(cd.cddb_id != cur_goto_id)
     {
 	make_goto_menu();
 	update_editor();
@@ -575,13 +578,13 @@ gint slow_timer( gpointer *data )
 	cd.sc.cdsc_audiostatus != CDROM_AUDIO_PAUSED )
     {
 	if( cd.play_method == REPEAT_CD )
-	    tcd_playtracks( &cd, cd.first_t, cd.last_t );
+	    tcd_playtracks( &cd, cd.first_t, cd.last_t, prefs.only_use_trkind);
     }
 
     /* see if we need to scan for a new disc */
-    if(cd.isplayable) 
+/*    if(cd.isplayable) 
     {
-	tcd_gettime(&cd);
+	tcd_post_init(&cd);
 	adjust_status();
 
 	if(cd.err) 
@@ -594,7 +597,7 @@ gint slow_timer( gpointer *data )
     }
     else
     {
-	tcd_readtoc(&cd);
+	tcd_post_init(&cd);
 	if(!cd.err)
 	    tcd_readdiskinfo(&cd);
 	else
@@ -605,7 +608,7 @@ gint slow_timer( gpointer *data )
 	    cd.repeat_track = -1;    
 	    update_editor();
 	}
-    }
+    }*/
 
     /* is a cddb operation going on? */
     cddb = g_file_test(gnome_util_home_file(".cddbstatus_lock"), G_FILE_TEST_EXISTS);
@@ -694,7 +697,7 @@ void make_goto_menu()
 
 gint fast_timer( gpointer *data )
 {
-    if( cd.isplayable ) {
+    if(cd.isplayable) {
 	tcd_gettime(&cd);
 	if( cd.err ) {
 /*	   cd.isplayable = FALSE;
@@ -705,7 +708,7 @@ gint fast_timer( gpointer *data )
     }
     status_changed();
     if((cd.play_method==REPEAT_TRK) && (cd.cur_t != cd.repeat_track))
-	tcd_playtracks(&cd, cd.repeat_track, -1);
+	tcd_playtracks(&cd, cd.repeat_track, -1, prefs.only_use_trkind);
     return 1;
 }
 
@@ -917,6 +920,7 @@ void reload_info(int signal)
     draw_status();
 }
 
+
 void exit_action(void)
 {
     switch(prefs.exit_action)
@@ -957,7 +961,7 @@ void start_action(void)
     switch(prefs.start_action)
     {
     case StartPlaying:
-	tcd_playtracks(&cd, cd.first_t, cd.last_t);
+	tcd_playtracks(&cd, cd.first_t, cd.last_t, prefs.only_use_trkind);
 	if(cd.isplayable)
 	{
 	    make_goto_menu();
